@@ -3,14 +3,11 @@ from .decidir_sdk.DecidirSDK import DecidirSDK
 
 
 class SDK:
-    def __init__(self, merchant: dict, processor: str = None, merchant_cadena: dict = None):
+    def __init__(self, merchant: dict, merchant_cadena: dict, processor: str = None, marketplace: bool = False):
         # Si se le indica el procesador
-        self.processor = processor
         self._sdk = None
         if processor == 'mercadopago':
-            self._sdk = MercadoPagoSDK(merchant)
-        elif processor == 'mp_marketplace':
-            self._sdk = MercadoPagoSDK(merchant, marketplace=True)
+            self._sdk = MercadoPagoSDK(merchant, marketplace=marketplace)
         elif processor == 'decidir':
             self._sdk = DecidirSDK(merchant, merchant_cadena)
 
@@ -29,8 +26,5 @@ class SDK:
     def refund(self):
         return self._sdk.refund()
 
-    def which(self):
-        return self.processor
-
     def ok(self):
         return self._sdk.ok()
